@@ -1,5 +1,5 @@
 from .bayesian_model import BayesianModel
-from .density import Density
+from .distribution_model import DistributionModel
 from .log_target_model import LogTargetModel
 from .logistic_regression import LogisticRegression
 from .mlp import MLP
